#ifndef NT2_INCLUDE_CONSTANTS_EXPX2C2_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_EXPX2C2_HPP_INCLUDED

#include <nt2/exponential/include/constants/expx2c2.hpp>

#endif
